@@ -2,7 +2,6 @@ package fileselector
 
 import (
 	"github.com/charmbracelet/lipgloss"
-	"github.com/noahgorstein/jqp/tui/styles"
 )
 
 type Styles struct {
@@ -13,8 +12,8 @@ type Styles struct {
 
 func DefaultStyles() (s Styles) {
 	s.containerStyle = lipgloss.NewStyle().Align(lipgloss.Left).PaddingLeft(1)
-	s.inputLabelStyle = lipgloss.NewStyle().Bold(true).Foreground(styles.BLUE)
-	s.promptStyle = lipgloss.NewStyle().Bold(true).Foreground(styles.PINK)
+	s.inputLabelStyle = lipgloss.NewStyle().Bold(true)
+	s.promptStyle = lipgloss.NewStyle().Bold(true)
 
 	return s
 }
