@@ -4,30 +4,29 @@ import (
 	"github.com/charmbracelet/bubbles/help"
 	"github.com/charmbracelet/bubbles/key"
 	"github.com/charmbracelet/bubbletea"
+
 	"github.com/noahgorstein/jqp/tui/bubbles/state"
 	"github.com/noahgorstein/jqp/tui/theme"
 )
 
 type Bubble struct {
 	state  state.State
-	width  int
 	help   help.Model
 	keys   keyMap
 	Styles Styles
 }
 
-func New(theme theme.Theme) Bubble {
-
+func New(jqtheme theme.Theme) Bubble {
 	styles := DefaultStyles()
-	help := help.NewModel()
-	help.Styles.ShortKey = styles.helpKeyStyle.Foreground(theme.Primary)
-	help.Styles.ShortDesc = styles.helpTextStyle.Foreground(theme.Secondary)
-	help.Styles.ShortSeparator = styles.helpSeparatorStyle.Foreground(theme.Inactive)
+	model := help.New()
+	model.Styles.ShortKey = styles.helpKeyStyle.Foreground(jqtheme.Primary)
+	model.Styles.ShortDesc = styles.helpTextStyle.Foreground(jqtheme.Secondary)
+	model.Styles.ShortSeparator = styles.helpSeparatorStyle.Foreground(jqtheme.Inactive)
 
 	return Bubble{
 		state:  state.Query,
 		Styles: styles,
-		help:   help,
+		help:   model,
 		keys:   keys,
 	}
 }
@@ -50,17 +49,15 @@ func (b Bubble) collectHelpBindings() []key.Binding {
 }
 
 func (b *Bubble) SetWidth(width int) {
-	b.Styles.helpbarStyle.Width(width - 1)
+	b.Styles.helpbarStyle = b.Styles.helpbarStyle.Width(width - 1)
 }
 
-func (b Bubble) Init() tea.Cmd {
+func (Bubble) Init() tea.Cmd {
 	return nil
 }
 
 func (b Bubble) View() string {
-
 	return b.Styles.helpbarStyle.Render(b.help.ShortHelpView(b.collectHelpBindings()))
-
 }
 
 func (b *Bubble) SetState(mode state.State) {
@@ -68,12 +65,11 @@ func (b *Bubble) SetState(mode state.State) {
 }
 
 func (b Bubble) Update(msg tea.Msg) (Bubble, tea.Cmd) {
-
 	var cmd tea.Cmd
 
-	switch msg := msg.(type) {
-	case tea.WindowSizeMsg:
+	if msg, ok := msg.(tea.WindowSizeMsg); ok {
 		b.SetWidth(msg.Width)
 	}
+
 	return b, tea.Batch(cmd)
 }
