@@ -7,6 +7,7 @@ import (
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
+
 	"github.com/noahgorstein/jqp/tui/theme"
 )
 
@@ -19,10 +20,10 @@ type Bubble struct {
 	width    int
 }
 
-func New(theme theme.Theme) Bubble {
+func New(jqtheme theme.Theme) Bubble {
 	styles := DefaultStyles()
-	styles.containerStyle = styles.containerStyle.BorderForeground(theme.Inactive)
-	styles.infoStyle = styles.infoStyle.BorderForeground(theme.Inactive)
+	styles.containerStyle = styles.containerStyle.BorderForeground(jqtheme.Inactive)
+	styles.infoStyle = styles.infoStyle.BorderForeground(jqtheme.Inactive)
 	v := viewport.New(1, 1)
 	b := Bubble{
 		Styles:   styles,
@@ -33,23 +34,20 @@ func New(theme theme.Theme) Bubble {
 }
 
 func (b *Bubble) SetBorderColor(color lipgloss.TerminalColor) {
-	b.Styles.containerStyle.BorderForeground(color)
-	b.Styles.infoStyle.BorderForeground(color)
+	b.Styles.containerStyle = b.Styles.containerStyle.BorderForeground(color)
+	b.Styles.infoStyle = b.Styles.infoStyle.BorderForeground(color)
 }
 
 func (b *Bubble) SetSize(width, height int) {
 	b.width = width
 	b.height = height
 
-	b.Styles.containerStyle.
+	b.Styles.containerStyle = b.Styles.containerStyle.
 		Width(width - b.Styles.containerStyle.GetHorizontalFrameSize()/2).
 		Height(height - b.Styles.containerStyle.GetVerticalFrameSize())
 
-	b.viewport.Width = width - b.Styles.containerStyle.GetHorizontalFrameSize() - 3
+	b.viewport.Width = width - b.Styles.containerStyle.GetHorizontalFrameSize()
 	b.viewport.Height = height - b.Styles.containerStyle.GetVerticalFrameSize() - 3
-
-	b.SetContent(b.content)
-
 }
 
 func (b *Bubble) GetContent() string {
@@ -75,7 +73,6 @@ func (b *Bubble) ScrollToTop() {
 }
 
 func (b Bubble) View() string {
-
 	scrollPercent := fmt.Sprintf("%3.f%%", b.viewport.ScrollPercent()*100)
 
 	info := b.Styles.infoStyle.Render(fmt.Sprintf("%s | %s", lipgloss.NewStyle().Italic(true).Render("output"), scrollPercent))
@@ -87,24 +84,16 @@ func (b Bubble) View() string {
 	return b.Styles.containerStyle.Render(content)
 }
 
-func (b Bubble) Init() tea.Cmd {
+func (Bubble) Init() tea.Cmd {
 	return nil
 }
 
 func (b Bubble) Update(msg tea.Msg) (Bubble, tea.Cmd) {
-
 	var (
 		cmd  tea.Cmd
 		cmds []tea.Cmd
 	)
 
-	switch msg := msg.(type) {
-	case tea.KeyMsg:
-		switch msg.String() {
-		case "a":
-		}
-	}
-
 	b.viewport, cmd = b.viewport.Update(msg)
 	cmds = append(cmds, cmd)
 
